summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kautoconfig.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kautoconfig.h')
-rw-r--r--kopete/libkopete/kautoconfig.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kopete/libkopete/kautoconfig.h b/kopete/libkopete/kautoconfig.h
index 0aecd380..b582e85a 100644
--- a/kopete/libkopete/kautoconfig.h
+++ b/kopete/libkopete/kautoconfig.h
@@ -25,7 +25,7 @@
#include "kopete_export.h"
-class KConfig;
+class TDEConfig;
class TQWidget;
/**
@@ -119,12 +119,12 @@ signals:
public:
/**
* Constructor.
* @param kconfig - KConfig to use when retrieving/saving the widgets
* that KAutoConfig knows about.
* @param parent - Parent object.
* @param name - Object name.
*/
- KAutoConfig( KConfig *kconfig, TQObject *parent=0, const char *name=0 );
+ KAutoConfig( TDEConfig *kconfig, TQObject *parent=0, const char *name=0 );
/**
* Constructor.
@@ -243,9 +243,9 @@ public slots:
protected:
/**
* KConfigBase object used to get/save values.
*/
- KConfig *config;
+ TDEConfig *config;
/**
* Map of the classes and the signals that they emit when changed.
*/
@@ -119,12 +119,12 @@ signals:
/**
* Constructor.
- * @param kconfig - KConfig to use when retrieving/saving the widgets
+ * @param kconfig - TDEConfig to use when retrieving/saving the widgets
* that KAutoConfig knows about.
* @param parent - Parent object.
@@ -243,9 +243,9 @@ public slots:
protected:
/**
- * KConfigBase object used to get/save values.
+ * TDEConfigBase object used to get/save values.
*/